@@ -6,12 +6,12 @@ C     PROGRAM 5.2.1   POWER SPECTRUM
 C-----------------------------------------------------------------------
 C     ** DESIGNED BY H. AKAIKE, THE INSTITUTE OF STATISTICAL MATHEMATICS
 C     ** PROGRAMMED BY E. ARAHATA, THE INSTITUTE OF STATISTICAL MATHEMAT
-C	  TOKYO
+C        TOKYO
 C     ** DATE OF THE LATEST REVISION: MARCH 25, 1977
 C     ** THIS PROGRAM WAS ORIGINALLY PUBLISHED IN
-C	 "DAINAMIKKU SISTEMU NO TOKEI-TEKI KAISEKI TO SEIGYO (STATISTICA
-C	 ANALYSIS AND CONTROL OF DYNAMIC SYSTEMS)" BY H. AKAIKE AND
-C	 T. NAKAGAWA, SAIENSU-SHA, TOKYO, 1972 (IN JAPANESE)
+C        "DAINAMIKKU SISTEMU NO TOKEI-TEKI KAISEKI TO SEIGYO (STATISTICA
+C        ANALYSIS AND CONTROL OF DYNAMIC SYSTEMS)" BY H. AKAIKE AND
+C        T. NAKAGAWA, SAIENSU-SHA, TOKYO, 1972 (IN JAPANESE)
 C-----------------------------------------------------------------------
 C     THIS PROGRAM COMPUTES POWER SPECTRUM ESTIMATES FOR TWO
 C     TRIGONOMETRIC WINDOWS OF BLACKMAN-TUKEY TYPE BY GOERTZEL METHOD.
@@ -25,12 +25,15 @@ C
 cc      !DEC$ ATTRIBUTES DLLEXPORT :: AUSPECF
 c      USE DFLIB
 C
-      IMPLICIT REAL*8(A-H,O-Z)
+cxx      IMPLICIT REAL*8(A-H,O-Z)
 c      DIMENSION CXX(1001),FC(1001),P1(1001),P2(1001),Q(1001)
 c      DIMENSION A1(10),A2(10)
-      DIMENSION CXX1(LAGH1),CXX(LAGH1)
-      DIMENSION FC(LAGH1),P1(LAGH1),P2(LAGH1),Q(LAGH1)
-      DIMENSION A1(2),A2(3)
+cxx      DIMENSION CXX1(LAGH1),CXX(LAGH1)
+cxx      DIMENSION FC(LAGH1),P1(LAGH1),P2(LAGH1),Q(LAGH1)
+cxx      DIMENSION A1(2),A2(3)
+      INTEGER :: N, LAGH1
+      REAL(8) :: CXX1(LAGH1), P1(LAGH1), P2(LAGH1), Q(LAGH1)
+      REAL(8) :: CXX(LAGH1), FC(LAGH1), A1(2), A2(3)
 C
 C     INPUT / OUTPUT DATA FILE OPEN
 c	CHARACTER(100) DFNAM
@@ -73,7 +76,9 @@ c      DO 10 I=2,LAGH
 c   10 CXX(I)=CXX(I)+CXX(I)
       CXX(1)=CXX1(1)
       DO 10 I=2,LAGH1-1
-   10 CXX(I)=CXX1(I)+CXX1(I)
+cxx   10 CXX(I)=CXX1(I)+CXX1(I)
+      CXX(I)=CXX1(I)+CXX1(I)
+   10 CONTINUE
       CXX(LAGH1)=CXX1(LAGH1)
 C     F-COS TRANSFORMATION
       CALL FGERCO(CXX,LAGH1,FC,LAGH1)
