@@ -1,4 +1,4 @@
-	SUBROUTINE AUTCORF(X,N,CXX,CN,LAGH1,XMEAN)
+      SUBROUTINE AUTCORF(X,N,CXX,CN,LAGH1,XMEAN)
 C
       INCLUDE 'timsac_f.h'
 C
@@ -6,12 +6,12 @@ C     PROGRAM 5.1.1   AUTO CORRELATION
 C-----------------------------------------------------------------------
 C     ** DESIGNED BY H. AKAIKE, THE INSTITUTE OF STATISTICAL MATHEMATICS
 C     ** PROGRAMMED BY E. ARAHATA, THE INSTITUTE OF STATISTICAL MATHEMAT
-C	  TOKYO
+C         TOKYO
 C     ** DATE OF THE LATEST REVISION: MARCH 25, 1977
 C     ** THIS PROGRAM WAS ORIGINALLY PUBLISHED IN
-C	 "DAINAMIKKU SISTEMU NO TOKEI-TEKI KAISEKI TO SEIGYO (STATISTICA
-C	 ANALYSIS AND CONTROL OF DYNAMIC SYSTEMS)" BY H. AKAIKE AND
-C	 T. NAKAGAWA, SAIENSU-SHA, TOKYO, 1972 (IN JAPANESE)
+C         "DAINAMIKKU SISTEMU NO TOKEI-TEKI KAISEKI TO SEIGYO (STATISTICA
+C         ANALYSIS AND CONTROL OF DYNAMIC SYSTEMS)" BY H. AKAIKE AND
+C         T. NAKAGAWA, SAIENSU-SHA, TOKYO, 1972 (IN JAPANESE)
 C-----------------------------------------------------------------------
 C     THIS PROGRAM REQUIRES FOLLOWING INPUTS:
 C     N: LENGTH OF DATA
@@ -25,18 +25,21 @@ C     AUTO CORRELATIONS (NORMALIZED COVARIANCES).
 C
 cc      !DEC$ ATTRIBUTES DLLEXPORT :: AUTCORF
 C
-      IMPLICIT REAL*8 (A-H,O-Z)
+cxx      IMPLICIT REAL*8 (A-H,O-Z)
 c      DIMENSION X(5000),CXX(1001),CN(1001)
 c	 REAL*4 DFORM
 c      DIMENSION  DFORM(20)
-      DIMENSION X(N),X1(N),CXX(LAGH1),CN(LAGH1)
+cxx      DIMENSION X(N),X1(N),CXX(LAGH1),CN(LAGH1)
+      INTEGER :: N, LAGH1
+      REAL(8) :: X(N), CXX(LAGH1), CN(LAGH1), XMEAN
+      REAL(8) :: X1(N), CX0
 C
 C     INPUT / OUTPUT DATA FILE OPEN
 c	CHARACTER(100) DFNAM
 c	CALL SETWND
 c	DFNAM='autcor.out'
-c	CALL FLOPN3(DFNAM,NFL)
-c	IF (NFL.EQ.0) GO TO 999
+c      CALL FLOPN3(DFNAM,NFL)
+c      IF (NFL.EQ.0) GO TO 999
 C     INITIAL CONDITION INPUT AND PRINT OUT
 c      READ(5,1) N,LAGH
 c      WRITE(6,50)
@@ -52,7 +55,9 @@ c      WRITE(6,54)
 c      DO 220 I=1,N
 c  220 WRITE(6,55) I,X(I)
       DO 220 I=1,N
-  220 X1(I)=X(I)
+cxx  220 X1(I)=X(I)
+      X1(I)=X(I)
+  220 CONTINUE
 C     MEAN DELETION
       CALL DMEADL(X1,N,XMEAN)
 C     AUTO COVARIANCE COMPUTATION
