@@ -4,7 +4,7 @@
 
 extern void  F77_NAME(bsubstf) (double*,int*,int*,int*,int*,int*,int*,int*,double*,double*,int*,double*,double*,double*,double*,double*,double*,double*,double*,double*,double*,int*,double*,double*,double*,double*,double*,double*,double*,double*,double*,double*,double*,double*,double*,double*,double*);
 
-SEXP bsubst(SEXP y, SEXP n, SEXP mtype, SEXP lag, SEXP nreg, SEXP cstep, SEXP reg, SEXP tlag)
+SEXP BsubstC(SEXP y, SEXP n, SEXP mtype, SEXP lag, SEXP nreg, SEXP cstep, SEXP reg, SEXP tlag)
 {
     double *d1,*d3,*d4,*d5,*d6,*d7,*d8,*d9,*d10,*d11,*d12,*d13,*d14,*d15,*d16,*d17,*d18,*d19,*d20;
     double *d21,*d22,*d23,*d24,*d25,*d26,*d27,*d28,*d29;
