@@ -4,7 +4,7 @@
 
 extern void F77_NAME(mulmarf)  (double*,int*,int*,double*,int*,double*,double*,double*,double*,double*,int*,double*,double*,int*,int*,double*,double*,double*,double*,double*,double*,double*,int*,double*);
 
-SEXP mulmar( SEXP y, SEXP n, SEXP d, SEXP calb, SEXP lag )
+SEXP MulmarC( SEXP y, SEXP n, SEXP d, SEXP calb, SEXP lag )
 {
     double *d1,*d2,*d3,*d4,*d5,*d6,*d7,*d8,*d9,*d10,*d11,*d12,*d13,*d14,*d15,*d16,*d17;
     int    *i1,*i2,*i3,*i4,*i5,*i6,*i7;
