@@ -6,12 +6,12 @@ C     PROGRAM 5.3.3   MULTIPLE UNOISE
 C-----------------------------------------------------------------------
 C     ** DESIGNED BY H. AKAIKE, THE INSTITUTE OF STATISTICAL MATHEMATICS
 C     ** PROGRAMMED BY E. ARAHATA, THE INSTITUTE OF STATISTICAL MATHEMAT
-C	  TOKYO
+C         TOKYO
 C     ** DATE OF THE LATEST REVISION: MARCH 25, 1977
 C     ** THIS PROGRAM WAS ORIGINALLY PUBLISHED IN
-C	 "DAINAMIKKU SISTEMU NO TOKEI-TEKI KAISEKI TO SEIGYO (STATISTICA
-C	 ANALYSIS AND CONTROL OF DYNAMIC SYSTEMS)" BY H. AKAIKE AND
-C	 T. NAKAGAWA, SAIENSU-SHA, TOKYO, 1972 (IN JAPANESE)
+C         "DAINAMIKKU SISTEMU NO TOKEI-TEKI KAISEKI TO SEIGYO (STATISTICA
+C         ANALYSIS AND CONTROL OF DYNAMIC SYSTEMS)" BY H. AKAIKE AND
+C         T. NAKAGAWA, SAIENSU-SHA, TOKYO, 1972 (IN JAPANESE)
 C-----------------------------------------------------------------------
 C     THIS PROGRAM COMPUTES RELATIVE POWER CONTRIBUTIONS IN DIFFERENTIAL
 C     AND INTEGRATED FORM, ASSUMING THE ORTHOGONALITY BETWEEN NOISE
@@ -23,14 +23,20 @@ C
 cc      !DEC$ ATTRIBUTES DLLEXPORT :: MULNOSF
 c      USE DFLIB
 C
-      IMPLICIT REAL*8(A-H,O-W)
-      IMPLICIT COMPLEX*16(X-Z)
-      INTEGER H,H1
+cxx      IMPLICIT REAL*8(A-H,O-W)
+cxx      IMPLICIT COMPLEX*16(X-Z)
+cxx      INTEGER H,H1
 c      COMMON G,GR,GI,LG,H,JJF
 c      DIMENSION SD(10,10),A(30,10,10),X(10,10)
 c      DIMENSION G(31),RS(10,10),R(10,10)
-      DIMENSION SD(IP,IP),A(L,IP,IP),X(IP,IP)
-      DIMENSION G(L+1),RS1(IP,IP),RS2(IP,IP,H+1),R(IP,IP,H+1)
+cxx      DIMENSION SD(IP,IP),A(L,IP,IP),X(IP,IP)
+cxx      DIMENSION G(L+1),RS1(IP,IP),RS2(IP,IP,H+1),R(IP,IP,H+1)
+      INTEGER :: H, L, IP
+      REAL(8) :: SD(IP,IP), A(L,IP,IP), RS1(IP,IP), RS2(IP,IP,H+1),
+     1           R(IP,IP,H+1)
+      INTEGER :: H1
+      REAL(8) :: G(L+1), GR, GI, CST0, CST1
+      COMPLEX(kind(0d0)) :: X(IP,IP), XDET
 C     INPUT / OUTPUT DATA FILE OPEN
 c	CALL SETWND
 c	CALL FLOPN2(NFL)
@@ -48,12 +54,17 @@ C     SD INPUT
 c      CALL REMATX(SD,IP,IP,1,MJ1,MJ1)
 C     A INPUT
 c      CALL REMAT3(A,L,IP,IP,1,MJ0,MJ1,MJ1)
-  310 H1=H+1
+cxx  310 H1=H+1
+      H1=H+1
 C     SD NORMALIZATION
-      DO 100 I=1,IP
+cxx      DO 100 I=1,IP
+      DO 101 I=1,IP
       DO 100 J=1,IP
 c  100 RS(I,J)=SD(I,J)/DSQRT(SD(I,I)*SD(J,J))
-  100 RS1(I,J)=SD(I,J)/DSQRT(SD(I,I)*SD(J,J))
+cxx  100 RS1(I,J)=SD(I,J)/DSQRT(SD(I,I)*SD(J,J))
+      RS1(I,J)=SD(I,J)/DSQRT(SD(I,I)*SD(J,J))
+  100 CONTINUE
+  101 CONTINUE
 C     INITIAL CONDITION PRINT OUT
 c      WRITE(6,59)
 c      WRITE(6,60)
@@ -67,7 +78,8 @@ c      CALL SUBMPR(RS,IP,IP,IP,IP)
 C     A PRINT OUT
 c      WRITE(6,420)
 c      CALL PRMAT3(A,L,IP,IP,0,MJ0,MJ1,MJ1)
-  410 DO 10 JF=1,H1
+cxx  410 DO 10 JF=1,H1
+      DO 10 JF=1,H1
       JJF=JF
 C     AF COMPUTATION
       DO 40 II=1,IP
@@ -78,8 +90,11 @@ C     AF COMPUTATION
    42 G(1)=CST0
    43 DO 45 I=1,L
       I1=I+1
-   45 G(I1)=-A(I,II,JJ)
-   44 LG=L
+cxx   45 G(I1)=-A(I,II,JJ)
+      G(I1)=-A(I,II,JJ)
+   45 CONTINUE
+cxx   44 LG=L
+      LG=L
 c      CALL FGER1
       CALL FGER1(G,GR,GI,LG,H,JJF)
       X(II,JJ)=DCMPLX(GR,GI)
