@@ -154,7 +154,7 @@ C
       CALL DINIT(YORI,(H+1)*D,CST0)
       CALL DINIT(DMXT,D,CST0)
       CALL DINIT(DMIT,D,CST0)
-      CALL DINIT(AV,D,SCT0)
+      CALL DINIT(AV,D,CST0)
 C
 C     INITIAL CONDITION INPUT
 cc      READ(5,800) N,D,P,Q,H
