@@ -12,12 +12,12 @@ C      SUBROUTINE SPHASE(C,S,PH,LAGH1)
 C-----------------------------------------------------------------------
 C     ** DESIGNED BY H. AKAIKE, THE INSTITUTE OF STATISTICAL MATHEMATICS
 C     ** PROGRAMMED BY E. ARAHATA, THE INSTITUTE OF STATISTICAL MATHEMAT
-C	  TOKYO
+C         TOKYO
 C     ** DATE OF THE LATEST REVISION: MARCH 25, 1977
 C     ** THIS PROGRAM WAS ORIGINALLY PUBLISHED IN
-C	 "DAINAMIKKU SISTEMU NO TOKEI-TEKI KAISEKI TO SEIGYO (STATISTICA
-C	 ANALYSIS AND CONTROL OF DYNAMIC SYSTEMS)" BY H. AKAIKE AND
-C	 T. NAKAGAWA, SAIENSU-SHA, TOKYO, 1972 (IN JAPANESE)
+C         "DAINAMIKKU SISTEMU NO TOKEI-TEKI KAISEKI TO SEIGYO (STATISTICA
+C         ANALYSIS AND CONTROL OF DYNAMIC SYSTEMS)" BY H. AKAIKE AND
+C         T. NAKAGAWA, SAIENSU-SHA, TOKYO, 1972 (IN JAPANESE)
 C-----------------------------------------------------------------------
 C     THIS PROGRAM COMPUTES 1-INPUT,1-OUTPUT FREQUECNY RESPONSE FUNCTION
 C     ,GAIN,PHASE,COHERENCY AND RELATIVE ERROR STATISTICS.
@@ -30,16 +30,20 @@ C
 cc      !DEC$ ATTRIBUTES DLLEXPORT :: SGLFREF
 c      USE DFLIB
 C
-      IMPLICIT REAL*8(A-H,O-Z)
+cxx      IMPLICIT REAL*8(A-H,O-Z)
 c      DIMENSION P11(501),P22(501),C(501),S(501)
 c      DIMENSION R(501),PH(501),P(10,10)
-      DIMENSION P11(LAGH1),P22(LAGH1),C(LAGH1),S(LAGH1)
-	DIMENSION CP11(LAGH1),CP22(LAGH1),CC(LAGH1),CS(LAGH1)
-      DIMENSION R(LAGH1),PH(LAGH1),P(LAGH1,IP,IP)
+cxx      DIMENSION P11(LAGH1),P22(LAGH1),C(LAGH1),S(LAGH1)
+cxx      DIMENSION CP11(LAGH1),CP22(LAGH1),CC(LAGH1),CS(LAGH1)
+cxx      DIMENSION R(LAGH1),PH(LAGH1),P(LAGH1,IP,IP)
+      INTEGER :: INP, IOUT, N, LAGH1, IP
+      REAL(8) :: P(LAGH1,IP,IP), P11(LAGH1), P22(LAGH1), C(LAGH1),
+     1           S(LAGH1), CP11(LAGH1), CP22(LAGH1), CC(LAGH1),
+     2           CS(LAGH1), R(LAGH1), PH(LAGH1)
 C     INPUT / OUTPUT DATA FILE OPEN
-c	CALL SETWND
-c	CALL FLOPN2(NFL)
-c	IF (NFL.EQ.0) GO TO 999
+c      CALL SETWND
+c      CALL FLOPN2(NFL)
+c      IF (NFL.EQ.0) GO TO 999
 C     ABSOLUTE DIMENSION USED FOR SUBROUTINE CALL
 c      MJ=10
 C     INPUT OUTPUT VARIABLE SPECIFICATION
@@ -82,20 +86,26 @@ c      S(I)=S(I)/P11(I)
 c   10 P22(I)=P22(I)/P11(I)
       CC(I)=C(I)/P11(I)
       CS(I)=S(I)/P11(I)
-   10 CP22(I)=P22(I)/P11(I)
+cxx   10 CP22(I)=P22(I)/P11(I)
+      CP22(I)=P22(I)/P11(I)
+   10 CONTINUE
 C     GAIN COMPUTATION
       DO 11 I=1,LAGH1
 c      R(I)=C(I)**2+S(I)**2
 c   11 P11(I)=DSQRT(R(I))
       R(I)=CC(I)**2+CS(I)**2
-   11 CP11(I)=DSQRT(R(I))
+cxx   11 CP11(I)=DSQRT(R(I))
+      CP11(I)=DSQRT(R(I))
+   11 CONTINUE
 C     PHASE COMPUTATION
 C      CALL SPHASE(C,S,PH,LAGH1)
       CALL SPHASE(CC,CS,PH,LAGH1)
 C    COHERENCY COMPUTATION
       DO 12 I=1,LAGH1
 c   12 P22(I)=R(I)/P22(I)
-   12 CP22(I)=R(I)/CP22(I)
+cxx   12 CP22(I)=R(I)/CP22(I)
+      CP22(I)=R(I)/CP22(I)
+   12 CONTINUE
 C     RELATIVE ERROR STATISTICS COMPUTATION
 c      CALL SGLERR(P22,R,N,LAGH1)
       CALL SGLERR(CP22,R,N,LAGH1)
@@ -125,8 +135,11 @@ C
       SUBROUTINE SGLARC(C,S,ARC,LAGH1)
 C     THIS SUBROUTINE COMPUTES RAW PHASES.
 C     (SINGLE CHANNEL)
-      IMPLICIT REAL*8(A-H,O-Z)
-      DIMENSION C(LAGH1),S(LAGH1),ARC(LAGH1)
+cxx      IMPLICIT REAL*8(A-H,O-Z)
+cxx      DIMENSION C(LAGH1),S(LAGH1),ARC(LAGH1)
+      INTEGER :: LAGH1
+      REAL(8) :: C(LAGH1), S(LAGH1), ARC(LAGH1)
+      REAL(8) :: PI, CST5
       PI=3.1415926536
       CST5=0.5D-00
       DO 10 I=1,LAGH1
@@ -135,7 +148,8 @@ cc   11 IF(S(I)) 14,15,16
 cc   12 IF(S(I)) 17,18,19
       IF(C(I).EQ.0) GO TO 12
       IF(C(I).GT.0) GO TO 13
-   11 IF(S(I).LT.0) GO TO 14
+cxx   11 IF(S(I).LT.0) GO TO 14
+      IF(S(I).LT.0) GO TO 14
       IF(S(I).EQ.0) GO TO 15
       IF(S(I).GT.0) GO TO 16
    12 IF(S(I).LT.0) GO TO 17
@@ -161,8 +175,11 @@ C
       SUBROUTINE SGLERR(CH,R,N,LAGH1)
 C     THIS SUBROUTINE COMPUTES RELATIVE ERROR STATISTICS.
 C     (SINGLE CHANNEL)
-      IMPLICIT REAL*8(A-H,O-Z)
-      DIMENSION CH(LAGH1),R(LAGH1)
+cxx      IMPLICIT REAL*8(A-H,O-Z)
+cxx      DIMENSION CH(LAGH1),R(LAGH1)
+      INTEGER :: N, LAGH1
+      REAL(8) :: CH(LAGH1), R(LAGH1)
+      REAL(8) :: D1, D2, CST0, CST1, CST100, E1, ER
 C     CONSTANTS D1,D2 COMPUTATION
       LAGH=LAGH1-1
       CALL SUBD12(N,LAGH,1,D1,D2)
@@ -189,8 +206,11 @@ C
       SUBROUTINE SGLPAC(ARC,PH,LAGH1)
 C     THIS SUBROUTINE MAKES PHASE CURVE CONTINUOUS.
 C     (SINGLE CHANNEL)
-      IMPLICIT REAL*8(A-H,O-Z)
-      DIMENSION ARC(LAGH1),PH(LAGH1)
+cxx      IMPLICIT REAL*8(A-H,O-Z)
+cxx      DIMENSION ARC(LAGH1),PH(LAGH1)
+      INTEGER :: LAGH1
+      REAL(8) :: ARC(LAGH1), PH(LAGH1)
+      REAL(8) :: PI, PI2, DK
       PI=3.1415926536
       PI2=PI+PI
       PH(1)=ARC(1)
@@ -210,10 +230,13 @@ C
       SUBROUTINE SPHASE(C,S,PH,LAGH1)
 C     THIS SUBROUTINE COMPUTES PHASE.
 C     (SINGLE CHANNEL)
-      IMPLICIT REAL*8(A-H,O-Z)
-      DIMENSION C(LAGH1),S(LAGH1),PH(LAGH1)
+cxx      IMPLICIT REAL*8(A-H,O-Z)
+cxx      DIMENSION C(LAGH1),S(LAGH1),PH(LAGH1)
 c      DIMENSION ARC(501)
-      DIMENSION ARC(LAGH1)
+cxx      DIMENSION ARC(LAGH1)
+      INTEGER :: LAGH1
+      REAL(8) :: C(LAGH1), S(LAGH1), PH(LAGH1)
+      REAL(8) :: ARC(LAGH1)
 C     ARCTANGENT COMPUTATION
       CALL SGLARC(C,S,ARC,LAGH1)
 C     PHASE COMPUTATION
