@@ -4,7 +4,7 @@
 
 extern void F77_NAME(simconf)  (int*,int*,int*,int*,int*,double*,double*,double*,double*,double*,double*,double*,double*,double*,double*);
 
-SEXP simcon(SEXP d, SEXP k, SEXP span, SEXP len, SEXP r, SEXP arcoef, SEXP impuls, SEXP v, SEXP weight)
+SEXP SimconC(SEXP d, SEXP k, SEXP span, SEXP len, SEXP r, SEXP arcoef, SEXP impuls, SEXP v, SEXP weight)
 {
     double *d1,*d2,*d3,*d4,*d5,*d6,*d7,*d8,*d9,*d10;
     int *i1,*i2,*i3,*i4,*i5;
